pub struct CompactToken(/* private fields */);Expand description
A compact representation of a Token with Char==u8 and CS==InternedCSName
as a single u32 (similar to the way plain TeX does it) – i.e. it is small and Copy, which yields a significant
performance improvement in the most performance critical parts of the code.
Values up to 0x8000_0000 are interpreted as interned control sequences, and the rest as character tokens. The downside
is that we need an interning table for control sequences, that needs passing around whenever we want to
make a Token from a control sequence name or display a CompactToken to the user in a comprehensible way.
(Also, we can only have 2³¹ control sequences in total, but that limit is ridiculously large.)